@@ -259,10 +259,7 @@ def add_to_cart(request, product_id=None):
 
                 if property.is_number_field:
                     try:
-                        if isinstance(value, unicode):
-                            # atof() on unicode string fails in some environments, like Czech
-                            value = value.encode("utf-8")
-                        value = locale.atof(value)
+                        value = lfs.core.utils.atof(value)
                     except ValueError:
                         value = locale.atof("0.0")
 
@@ -290,7 +287,7 @@ def add_to_cart(request, product_id=None):
                         return lfs.core.utils.set_message_cookie(
                             product.get_absolute_url(), msg)
 
-    if product.active_packing_unit:
+    if product.get_active_packing_unit():
         quantity = lfs.catalog.utils.calculate_real_amount(product, quantity)
 
     cart = cart_utils.get_or_create_cart(request)
@@ -417,7 +414,7 @@ def refresh_cart(request):
                 message = _(u"Sorry, but '%(product)s' is only %(amount)s times available.") % {"product": item.product.name, "amount": amount}
 
 
-        if item.product.active_packing_unit:
+        if item.product.get_active_packing_unit():
             item.amount = lfs.catalog.utils.calculate_real_amount(item.product, float(amount))
         else:
             item.amount = amount
