@@ -5,6 +5,7 @@ import math
 from django.conf import settings
 from django.core.cache import cache
 from django.db import connection
+from django.core.exceptions import FieldError
 
 # import lfs
 import lfs.catalog.models
@@ -36,7 +37,7 @@ def get_current_top_category(request, obj):
 
     return category
 
-
+# DEPRECATED 0.6
 def get_current_product_category(request, product):
     """Returns product category based on actual categories of the given product
     and the last visited category.
@@ -48,6 +49,7 @@ def get_current_product_category(request, product):
     return product.get_current_category(request)
 
 
+# DEPRECATED 0.6
 def get_property_groups(category):
     """Returns all property groups for given category
     """
@@ -350,7 +352,7 @@ def get_product_filters(category, product_filter, price_filter, sorting):
                 }]
             continue
         else:
-            if not properties.has_key(row[0]):
+            if not row[0] in properties:
                 properties[row[0]] = []
             properties[row[0]].append({
                 "id": row[0],
@@ -504,7 +506,11 @@ def get_filtered_products_for_category(category, filters, price_filter, sorting)
         products = lfs.catalog.models.Product.objects.filter(pk__in=matched_product_ids)
 
     if sorting:
-        products = products.order_by(sorting)
+        try:
+            products = products.order_by(sorting)
+        except FieldError:
+            # ignore invalid sort order which may be stored in the session
+            pass
 
     return products
 
@@ -654,6 +660,7 @@ def _calculate_quantity(product_ids, property_id, min, max):
     return amount
 
 
+# DEPRECATED 0.6
 def calculate_packages(product, quantity):
     """Returns amount of packages passed on passes product and quantity.
     DEPRECATED.
@@ -662,6 +669,7 @@ def calculate_packages(product, quantity):
     return math.ceil(quantity / product.packing_unit)
 
 
+# DEPRECATED 0.6
 def calculate_real_amount(product, quantity):
     """Returns the amount of pieces in package units. DEPRECATED.
     """
