@@ -1,4 +1,5 @@
 # python imports
+import locale
 import math
 import urllib
 
@@ -72,8 +73,12 @@ def calculate_packing(request, id, quantity=None, with_properties=False, as_stri
 
     if quantity is None:
         try:
-            quantity = float(request.POST.get("quantity"))
-        except (TypeError, ValueError):
+            quantity = request.POST.get("quantity")
+            if isinstance(quantity, unicode):
+                # atof() on unicode string fails in some environments, like Czech
+                quantity = quantity.encode("utf-8")
+            quantity = locale.atof(quantity)
+        except (AttributeError, TypeError, ValueError):
             quantity = 1
 
     packing_amount, packing_unit = product.get_packing_info()
@@ -339,8 +344,8 @@ def category_products(request, slug, start=1, template_name="lfs/catalog/categor
         default_sorting = settings.LFS_PRODUCTS_SORTING
     except AttributeError:
         default_sorting = "price"
-
     sorting = request.session.get("sorting", default_sorting)
+
     product_filter = request.session.get("product-filter", {})
     product_filter = product_filter.items()
 
