@@ -1,5 +1,6 @@
 # django imports
 from django.core.management.base import BaseCommand
+from django.conf import settings
 
 SHOP_DESCRIPTION = """
 <h1 class="first-heading">Welcome to LFS!</h1>
@@ -34,6 +35,7 @@ class Command(BaseCommand):
         from lfs.core.models import Application
         from lfs.core.models import Country
         from lfs.core.models import Shop
+        from lfs.core.utils import import_symbol
 
         from portlets.models import Slot
         from portlets.models import PortletAssignment
@@ -89,9 +91,16 @@ class Command(BaseCommand):
         ShippingMethod.objects.create(name="Standard", priority=1, active=1)
 
         # Pages
-        Page.objects.create(title="Terms and Conditions", slug="terms-and-conditions", active=1, body="Enter your terms and conditions here.")
-        Page.objects.create(title="Imprint", slug="imprint", active=1, body="Enter your imprint here.")
+        p = Page.objects.create(title="Root", slug="", active=1, exclude_from_navigation=1)
+        p.id = 1; p.save()
+        p = Page.objects.create(title="Terms and Conditions", slug="terms-and-conditions", active=1, body="Enter your terms and conditions here.")
+        p.id = 2; p.save()
+        p = Page.objects.create(title="Imprint", slug="imprint", active=1, body="Enter your imprint here.")
+        p.id = 3; p.save()
+
+        # Order Numbers
+        ong = import_symbol(settings.LFS_ORDER_NUMBER_GENERATOR)
+        ong.objects.create(id="order_number")
 
         # Application object
-        Application.objects.create(version="0.6")
-
+        Application.objects.create(version="0.7")
