@@ -1,9 +1,10 @@
 # python imports
+from collections import deque
 import datetime
+from itertools import count
+import locale
 import sys
 import urllib
-from collections import deque
-from itertools import count
 
 # django imports
 from django.conf import settings
@@ -35,6 +36,15 @@ def l10n_float(string):
         return 0.0
 
 
+def atof(value):
+    """
+    locale.atof() on unicode string fails in some environments, like Czech.
+    """
+    if isinstance(value, unicode):
+        value = value.encode("utf-8")
+    return locale.atof(value)
+
+
 def get_default_shop(request=None):
     """Returns the default shop.
     """
@@ -397,4 +407,4 @@ def lfs_pagination(request, current_page, url='', getparam='start'):
         del getvars[getparam]
     if len(getvars.keys()) > 0:
         to_return['getvars'] = "&%s" % getvars.urlencode()
-    return to_return
\ No newline at end of file
+    return to_return
