@@ -70,7 +70,8 @@ class Address(models.Model):
     firstname = models.CharField(_("Firstname"), max_length=50)
     lastname = models.CharField(_("Lastname"), max_length=50)
     company_name = models.CharField(_("Company name"), max_length=50, blank=True, null=True)
-    street = models.CharField(_("Street"), max_length=100)
+    line1 = models.CharField(_("Line 1"), max_length=100, blank=True, null=True)
+    line2 = models.CharField(_("Line 2"), max_length=100, blank=True, null=True)
     zip_code = models.CharField(_("Zip code"), max_length=10)
     city = models.CharField(_("City"), max_length=50)
     state = models.CharField(_("State"), max_length=50, blank=True)
@@ -79,7 +80,7 @@ class Address(models.Model):
     email = models.EmailField(_("E-Mail"), blank=True, null=True, max_length=50)
 
     def __unicode__(self):
-        return "%s / %s" % (self.street, self.city)
+        return "%s / %s" % (self.line1, self.city)
 
 
 class BankAccount(models.Model):
