@@ -6,9 +6,9 @@ from django.core.urlresolvers import reverse
 from django.core import mail
 
 # lfs imports
+from lfs.customer.models import Address
 from lfs.core.models import Country
 from lfs.core.models import Shop
-from lfs.customer.models import Address
 from lfs.customer.models import CreditCard
 from lfs.customer.models import Customer
 from lfs.shipping.models import ShippingMethod
@@ -73,11 +73,11 @@ class AddressTestCase(TestCase):
             tax=tax,
         )
 
-        address1 = Address.objects.create(
+        self.address1 = Address.objects.create(
             firstname="John",
             lastname="Doe",
             company_name="Doe Ltd.",
-            street="Street 42",
+            line1="Street 42",
             city="Gotham City",
             zip_code="2342",
             country=de,
@@ -85,11 +85,11 @@ class AddressTestCase(TestCase):
             email="john@doe.com",
         )
 
-        address2 = Address.objects.create(
+        self.address2 = Address.objects.create(
             firstname="Jane",
             lastname="Doe",
             company_name="Doe Ltd.",
-            street="Street 43",
+            line1="Street 43",
             city="Smallville",
             zip_code="2443",
             country=de,
@@ -108,11 +108,14 @@ class AddressTestCase(TestCase):
             user=new_user,
             selected_shipping_method=shipping_method,
             selected_payment_method=payment_method,
-            selected_shipping_address=address1,
-            selected_invoice_address=address2,
+            selected_shipping_address=self.address1,
+            selected_invoice_address=self.address2,
         )
         self.c = Client()
 
+    def test_unicode(self):
+        self.assertEqual(self.address1.__unicode__(), u"%s / %s" % (self.address1.line1, self.address1.city))
+
     def test_address_page(self):
         """
         Tests that we can see a shipping and an invoice address
@@ -171,8 +174,13 @@ class AddressTestCase(TestCase):
         address_data = {'invoice_firstname': 'Joe', 'invoice_lastname': 'Bloggs',
                         'invoice-line1': 'de company name', 'invoice-line2': 'de street',
                         'invoice-city': 'Dallas', 'invoice-state': 'TX',
-                        'invoice-code': '84003', 'invoice-country': 'us',
-                        'shipping-country': 'ie'}
+                        'invoice-code': '84003', 'invoice-country': 'US',
+
+                        'shipping_firstname': 'Joe', 'shipping_lastname': 'Bloggs',
+                        'shipping-line1': 'de company name', 'shipping-line2': 'de street',
+                        'shipping-city': 'Dallas', 'shipping-state': 'TX',
+                        'shipping-code': '84003', 'shipping-country': 'US', }
+
         address_response = self.c.post(reverse('lfs_my_addresses'), address_data)
 
         self.assertEquals(Address.objects.count(), 4)
