@@ -177,14 +177,13 @@ def add_order(request):
     for discount in discounts:
         OrderItem.objects.create(
             order=order,
-            price_net=-(discount["price_net"] - discount["tax"]),
+            price_net=-discount["price_net"],
             price_gross=-discount["price_gross"],
             tax=-discount["tax"],
-
             product_sku=discount["sku"],
             product_name=discount["name"],
             product_amount=1,
-            product_price_net=-(discount["price_net"] - discount["tax"]),
+            product_price_net=-discount["price_net"],
             product_price_gross=-discount["price_gross"],
             product_tax=-discount["tax"],
         )
