@@ -2,6 +2,7 @@
 from django.conf import settings
 
 # lfs imports
+import lfs.core.signals
 from lfs.order.models import Order
 from lfs.order.settings import PAID, PAYMENT_FAILED, PAYMENT_FLAGGED
 from lfs.mail import utils as mail_utils
@@ -22,6 +23,8 @@ def mark_payment(pp_obj, order_state=PAID):
         order = Order.objects.get(uuid=order_uuid)
         if order is not None:
             if order.state != PAID and order_state == PAID:
+                lfs.core.signals.order_paid.send({"order": order})
+                # TODO: Why is here an order received mail sent?
                 if getattr(settings, 'LFS_SEND_ORDER_MAIL_ON_PAYMENT', False):
                     mail_utils.send_order_received_mail(order)
             order.state = order_state
