@@ -63,13 +63,7 @@ def search(request, template_name="lfs/search/search_results.html"):
     # Sorting
     sorting = request.session.get("sorting")
     if sorting:
-        try:
-            products = products.order_by(sorting)
-        except FieldError:
-            # this should not happen but I experienced it when
-            # switching on/off lfs_solr which uses different
-            # field specification for sorting but the same session key
-            del request.session["sorting"]
+        products = products.order_by(sorting)
 
     total = 0
     if products:
