@@ -40,7 +40,7 @@ $(function() {
             });
         });
     };
-    
+
     // Message ################################################################
 
     var message = $.cookie("message");
@@ -146,7 +146,8 @@ $(function() {
                 $(".standard-price-value").html(data["price"]);
                 $(".for-sale-price-value").html(data["for-sale-price"]);
                 $(".for-sale-standard-price-value").html(data["for-sale-standard-price"]);
-                // $.jGrowl(data["message"]);
+                $(".packing-result").html(data["packing-result"]);
+                $.jGrowl(data["message"]);
 
                 // Re-bind lightbox
                 $("a.product-image").lightBox({
