@@ -12,13 +12,14 @@ from django.conf import settings
 from django.contrib.redirects.models import Redirect
 from django.http import HttpResponseServerError
 
+
 class RedirectFallbackMiddleware(object):
     def process_response(self, request, response):
         if response.status_code != 404:
-            return response # No need to check for a redirect for non-404 responses.        
+            return response  # No need to check for a redirect for non-404 responses.
         parsed_url = urlparse(request.get_full_path())
         path = parsed_url.path
-        
+
         try:
             r = Redirect.objects.get(site__id__exact=settings.SITE_ID, old_path=path)
         except Redirect.DoesNotExist:
@@ -27,7 +28,7 @@ class RedirectFallbackMiddleware(object):
             # Try removing the trailing slash.
             try:
                 r = Redirect.objects.get(site__id__exact=settings.SITE_ID,
-                    old_path=path[:path.rfind('/')]+path[path.rfind('/')+1:])
+                    old_path=path[:path.rfind('/')] + path[path.rfind('/') + 1:])
             except Redirect.DoesNotExist:
                 pass
         if r is not None:
@@ -39,6 +40,7 @@ class RedirectFallbackMiddleware(object):
         # No redirect was found. Return the response.
         return response
 
+
 class ProfileMiddleware(object):
     """
     Displays hotshot profiling for any view.
@@ -51,16 +53,16 @@ class ProfileMiddleware(object):
     * Only tested on Linux
     """
     def process_request(self, request):
-        if request.GET.has_key('prof'):
+        if 'prof' in request.GET:
             self.tmpfile = tempfile.NamedTemporaryFile()
             self.prof = hotshot.Profile(self.tmpfile.name)
 
     def process_view(self, request, callback, callback_args, callback_kwargs):
-        if request.GET.has_key('prof'):
+        if 'prof' in request.GET:
             return self.prof.runcall(callback, request, *callback_args, **callback_kwargs)
 
     def process_response(self, request, response):
-        if request.GET.has_key('prof'):
+        if 'prof' in request.GET:
             self.prof.close()
 
             out = StringIO()
@@ -70,7 +72,7 @@ class ProfileMiddleware(object):
             stats = hotshot.stats.load(self.tmpfile.name)
             # stats.strip_dirs()
             stats.sort_stats('cumulative', )
-            # stats.sort_stats('time', )            
+            # stats.sort_stats('time', )
             stats.print_stats()
 
             sys.stdout = old_stdout
@@ -80,17 +82,18 @@ class ProfileMiddleware(object):
                 response.content = "<pre>" + stats_str + "</pre>"
 
         return response
-        
-        
+
+
 class AJAXSimpleExceptionResponse:
     def process_exception(self, request, exception):
         if settings.DEBUG:
             if request.is_ajax():
-                import sys, traceback
+                import sys
+                import traceback
                 (exc_type, exc_info, tb) = sys.exc_info()
                 response = "%s\n" % exc_type.__name__
                 response += "%s\n\n" % exc_info
-                response += "TRACEBACK:\n"    
+                response += "TRACEBACK:\n"
                 for tb in traceback.format_tb(tb):
                     response += "%s\n" % tb
-                return HttpResponseServerError(response)
\ No newline at end of file
+                return HttpResponseServerError(response)
